#' set the unit information from the column name
#'
#' @param df data frame
#'
#' @importFrom units as_units
#'
#' @export
#'
#' @examples
#' df <- readxl::read_xlsx("~/manuscript/su2024hrteffect/data/NF_chem_algae.xlsx")
#' get_udf(df)
#'
get_udf <- function(df) {
  v <- vtidy(colnames(df))
  u <- utidy(colnames(df))
  names(df) <- v
  for (icol in 1:ncol(df)) {
    if (!is.na(u[icol])) {
      df[, icol] <- set_u(df[[v[icol]]], u[icol])
    }
  }
  return(df)
}

#'
#' @export
set_u <- function(v, u){
  uCheck <- tryCatch(units::as_units(parse(text = u)),
        error = function(e) warning(e),
        finally = 1)
  if (!grepl("not recognized", uCheck)) {
    units(v) <- units::as_units(parse(text = u))
  }
  return(v)
}

#'
#' @export
#'
vtidy <- function(vunames) {
  return(gsub("_.*$", "", vunames))
}

#'
#' @export
#'
utidy <- function(vunames) {
  if (length(vunames) > 1) {
    return(sapply(vunames, FUN = function(x) {utidy(x)},
      simplify = TRUE, USE.NAMES = FALSE))
  }
  if (grepl("_", vunames)) {
    return(gsub("^.*_", "", vunames))
  }
  return(NA)
}
