#' Get the required object with unit shortcut
#'
#' @param ucode unit code
#' @param vcode variable code
#' @param modestr the specified mode, E: expression; M: markdown; G: gridtext
#' @param ucdb databse for ucode
#' @param lang language to use, default to "en", "cn" is also supported
#'
#' @return unit
#' @importFrom readxl read_xlsx
#' @importFrom tibble tibble
#' @importFrom dplyr filter left_join rename case_when select mutate
#' @importFrom purrr pluck
#' @importFrom tidyr pivot_longer
#' @importFrom langeR get_lang bracketing
#'
#' @export
#'
u <- function(ucode = NULL,
              vcode = NULL,
              modestr = "G",
              ucdb = readxl::read_xlsx(file.path(system.file(package = "uniteR"),
                                                 "unit.dict.xlsx"),
                                       sheet = "uc"),
              lang = "en",
              outdf = F
              ) {
    if (is.null(ucode)) {                 # unit code not supplied, fetched according to vc
        ucode = uc(vcode = vcode)
    }
    udf <- tibble::tibble(ucode = ucode) %>%
        dplyr::left_join(ucdb, by = "ucode") %>%
        dplyr::rename(ustr = dplyr::case_when(
                                    gsub("B", "", modestr) == "G" ~ paste0("gridtext", lang),
                                    gsub("B", "", modestr) == "M" ~ paste0("rmdstr", lang),
                                    gsub("B", "", modestr) == "E" ~ paste0("expstr", lang),
                                       TRUE ~ paste0("rmdstr", lang))) %>%
        dplyr::select(ucode, ustr)
    if (grepl("B", modestr)) {
        udf <- udf %>%
            dplyr::mutate(ustr = langeR::bracketing(ustr,
                                                    lang = lang,
                                                    type = "("))
    }
    if(any(is.na(udf$ustr))) {
        udf %>%
            dplyr::filter(is.na(ustr)) %>%
            dplyr::select(ucode) %>%
            euv(ucode = .)
        udf <- udf %>%
            dplyr::mutate(ustr = ifelse(is.na(ustr), ucode, ustr))
    }
    if(isFALSE(outdf)) {
        return(udf$ustr)
    }
    return(udf)
}

#' @export
um <- function(...) {
        return(u(..., modestr = "M"))
    }

#' @export
ug <- function(...) {
        return(u(..., modestr = "G"))
}

