#' get variable with specified format
#'
#' @param vcode variable code
#' @param lang language to use
#' @param modestr format to specify, M: markdown; G: gridtext
#' @param outdf return data frame or not
#' @param vcdb variable code databse
#'
#' @return variable
#' @importFrom readxl read_xlsx
#' @importFrom dplyr left_join rename select mutate filter
#' @importFrom langeR get_lang
#' @importFrom rmdify mder
#'
#' @export
#'
v <- function(
    vcode,
    modestr = "G",
    lang = langeR::get_lang(),
    outdf = FALSE,
    vcdb = readxl::read_xlsx(
      file.path(system.file(package = "uniteR"), "unit.dict.xlsx"),
      sheet = "vc"
    )) {
  vdf <- tibble::tibble(vcode = vcode) |>
    dplyr::left_join(vcdb, by = "vcode") |>
    dplyr::rename(vstr = paste0("vname", lang)) |>
    dplyr::select("vcode", "vstr", "ucode") |>
    dplyr::mutate(
      vstr = rmdify::mder(mdstr = .data$vstr, modestr = modestr, format = "")
    ) # TODO: this part should be done in rmdify
  if (any(is.na(vdf$vstr))) {
    # no record in databse
    vdf |>
      dplyr::filter(is.na(.data$vstr)) |>
      dplyr::select("vcode") |>
      euv(vcode = _)
  }
  if (isFALSE(outdf)) {
    return(vdf$vstr)
  }
  return(vdf)
}
