#' Get common used variables with unit
#'
#' @param vcode variable code
#' @param ucode unit code
#' @param ustr formatted unit string
#' @param lang language to use
#'
#' @return variable name with unit
#' @importFrom dplyr filter mutate pull
#' @importFrom langeR get_lang is_fullchar
#' @export
#'
vu <- function(vcode,
               ucode = NULL,
               ustr = NULL,
               lang = langeR::get_lang(),
               modestr = "G",
               outdf = F,
               ...) {
    vdf <- v(vcode,
             lang = lang,
             modestr = modestr,
             outdf = T)
    if(!is.null(ustr)) {
        if(length(ustr) != 1 && length(ustr) != length(vcode)) {
            warning("Length of `ustr` should equal to length of `vcode`\nTry to generate `ustr` with `ucode`")
            ustr <- NULL
        }
    }
    if(is.null(ustr)) {
        if(identical(ucode, NULL)) {
            ucode <- vdf %>%
                dplyr::pull(ucode)
        } else if(length(ucode) != 1 && length(ucode) != length(vcode)) {
            stop("Length of `ucode` should equal to length of `vcode`")
        }
        ustr = u(ucode = ucode,
                 modestr = paste0(modestr, "B"), # 增加括号
                 lang = lang,
                 outdf = F)
    }
    vdf <- vdf %>%
        dplyr::mutate(vstr = ifelse(is.na(vstr), vcode, vstr)) %>%
        dplyr::mutate(ustr = {{ ustr }}) %>%
        dplyr::mutate(ustr = ifelse(is.na(ustr), ucode, ustr)) %>%
        dplyr::mutate(sepstr = ifelse(langeR::is_fullchar(ustr, modestr = "L"),
                                      "",
                                      " ")) %>%
        dplyr::mutate(vustr = ifelse(is.na(ustr) || is.na(sepstr),
                                     vstr,
                                     paste0(vstr, sepstr, ustr))) %>%
        dplyr::mutate(vustr = gsub(" ?[\\(（]\\-[\\)）]$", "", vustr))
    if(isFALSE(outdf)) {
        return(vdf$vustr)
    }
    return(vdf)
}

