#' Get value with unit
#'
#' @param x value
#' @param ustr formatted unit string
#' @param vcode variable code
#' @param ucode unit code
#' @param modestr the specified mode, E: expression; M: markdown; G: gridtext
#' @param lang language
#'
#' @return 3 m s^s
#'
#' @importFrom langeR get_lang is_fullchar
#' @importFrom rmdify get_digfmt
#'
#' @export
#'
xu <- function (x,
                ucode = NULL,
                vcode = NULL,
                ustr = NULL,
                modestr = "M",
                lang = langeR::get_lang(),
                ...) {
    if(length(x) > 1) {
        xustr <- unlist(lapply(x, FUN = function(x) {
            xu(x = x, ustr = ustr, vcode = vcode, ucode = ucode, lang = lang)
        }))
        return(xustr)
    }
    # get formatted value
    .format <- case_when(modestr == "M" ~ "markdown",
                         modestr == "G" ~ "gridtext",
                         modestr == "L" ~ "latex",
                         modestr == "H" ~ "html",
                         modestr == "W" ~ "word",
                         TRUE ~ "markdown")
    if (is.numeric(x)) {
        x <- rmdify::get_digfmt(x, format = .format, ...)
    }
    if(is.null(ucode) & is.null(vcode) & is.null(ustr)) {
      return(x)
    }
    if (is.null(ustr)) {
        # get unit string
        if (is.null(ucode)) {                 # unit code not provided
            ucode <- uc(vcode = vcode)
        }
        ustr <- u(ucode = ucode, modestr = modestr)
    }
    if (ustr %in% c("-")) {
        return(x)
    }
    if (isTRUE(langeR::is_fullchar(ustr, modestr = "L"))) { #first unit is fullbite
        sepstr = ""
    } else {
        sepstr = " "
    }
    if(grepl("^%|^°", ustr) || ustr == "") {
        sepstr = ""
    }
    xustr <- paste0(x, sepstr, ustr)
    return(xustr)
}

